<?php

namespace REDO\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use REDO\E_REDO;

if (!defined('ABSPATH')) exit;

class CustomPostRedo extends Widget_Base
{


    public function get_name()
    {
        return 'customPostRedo';
    }

    public function get_title()
    {
        return __('Custom Post REDO');
    }

    public function get_icon()
    {
        return 'fa fa-eye';
    }

    public function get_categories()
    {
        return ['general'];
    }
    protected function _register_controls()
    {
        $customPostList = get_option('cptui_post_types');
        $_custom_posts = array();
        
        $_custom_posts_params = array();


        if ($customPostList) {
            foreach ($customPostList as $postList) {
                $_custom_posts_params[$postList["name"]] = $postList["label"];
                $_custom_posts[$postList["name"]]["type"] = $postList["name"];
                $_custom_posts[$postList["name"]]["label"] = $postList["label"];
                $supportsArray = array_flip($postList["supports"]);

                foreach ($supportsArray as $key => $value) {
                    $supportsArray[$key] = $key;
                }
                $_custom_posts[$postList["name"]]["supports"] = $supportsArray;
            }
        }

        $fields = E_REDO::prepareCustomFields();
        $customFieldsList = array();
        if ($fields) {
            foreach ($fields as $field) {
                $customFieldsList[$field["type"]]["customFields"] = $field["fields"];
            }
        }

        $this->start_controls_section(
            'custom-post',
            [
                'label' => 'Custom Post Type', 'Choose Post Type which you want to display',
            ]
        );
        foreach ($_custom_posts_params as $key => $value) {
            $this->add_control(
                'post_type-'.$key,
                [
                    'label' => $value,
                    'type' => \Elementor\Controls_Manager::CHOOSE,
                    'default' => '',
                    'options' => [
                        $key => __($key),
                    ],
                ]
            );
        }

        $this->end_controls_section();
        foreach ($_custom_posts as $key => $value) {

            $this->start_controls_section(
                $key .'-fields',
                [
                    'label' => $value["label"] . ' Fields', 'Chose additional fields',
                ]
            );
            $custom_params = $value["supports"];
            foreach ($custom_params as $pkey => $pvalue) {
                $this->add_control(
                    'post_field-'.$key .'-' . $pvalue,
                    [
                        'label' => $pvalue,
                        'type' => \Elementor\Controls_Manager::CHOOSE,
                        'default' => '',
                        'options' => [
                            $pkey => __($pvalue),
                        ],
                    ]
                );
            }
            $this->end_controls_section();

            foreach ($customFieldsList as $fkey => $fvalue) {
                if ($fkey == $value["type"]) {

                    $customList =  $fvalue["customFields"];
                    foreach ($customList as $ck => $cv) {
                        $customList[$ck] = $ck;
                    }
                    $this->start_controls_section(
                        $key . 'custom-fields',
                        [
                            'label' => $value["label"] . ' Custom Fields', 'Chose additional fields',
                        ]
                    );
                    foreach ($customList as $ckey) {

                        $this->add_control(
                            'customfield-'. $key . '-' . $ckey,
                            [
                                'label' => $ckey,
                                'type' => \Elementor\Controls_Manager::CHOOSE,
                                'default' => '',
                                'options' => [
                                    $ckey => __($ckey),
                                ],
                            ]
                        );
                    }
                    $this->end_controls_section();
                }
            }
        }
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $postTypes = array();
        foreach($settings as $key => $value) {  
            if (strpos($key, 'post_type-') !== false) {
                if(!empty($value)) {
                $postTypes[$value] = $value;
                }
            }
        }
?>

        <!-- HTML DESIGN HERE -->
        <?php if (!empty($postTypes)) : ?>
            <?php foreach ($postTypes as $postType) : ?>
                <div class="post-type-container <?php echo $postType ?>">
                    <h2><?php echo $postType ?></h2>
                    <?php
                   $args = array(
                    'post_type' => $postType,
                    'posts_per_page' => -1,
                    'orderby' => 'date'
                );
                    $query = new \WP_Query($args);
                    $postList = ($query->posts);
                    if (!empty($postList)) : ?>
                        <?php foreach ($postList as $myPost) : ?>
                            <div class="post-container <?php echo $postType ?>">
                                <h2><?php echo $myPost->post_title; ?></h2>
                                <?php 
                                    foreach($settings as $key => $value) {  
                                        if (strpos($key, 'post_field-'.$postType) !== false) {
                                            if(!empty($value)) { ?>
                                            <div class="'post-field '<?php echo $postType . ' ' . $value ?>">
                                                <?php if($value=="thumbnail") {
                                                    echo get_the_post_thumbnail($myPost->ID, 'medium');
                                                }
                                                else {
                                                    echo get_post_field("post_".$value, $myPost->ID);
                                                }?>
                                            </div>
                                            <?php }
                                        }
                                        if (strpos($key, 'customfield-'.$postType) !== false) { ?>
                                            <div class="'post-field '<?php echo $postType . ' ' . $value ?>">
                                                <?php $customField = get_field($value,$myPost->ID);
                                                    if(is_array($customField)) {
                                                        $size = 'thumbnail';
                                                        echo '<img src="' . esc_url( $customField['sizes'][$size] ) . '"/>';
                                                    }
                                                    else {
                                                        echo $customField;
                                                    }
                                                ?>
                                            </div>
                                        <?php
                                        }
                                        
                                    }
                                ?>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
        <!-- HTML END DESIGN HERE -->
<?php
    }
}
